function mode,data,x,h,bin=bin

;+
; NAME
;	mode
; PURPOSE
;	To return the most frequent value of a distribution.
; CALLING EXAMPLE
;	result=mode(data,[x,y,bin=0.1])
; INPUT
;	data, numerical input array
; OPTIONAL KEYWORD INPUT
;	bin, binwidth for histogram, default=1
; OUTPUT
;	Most frequent value with a resolution of binwidth, bin.
;	If the program finds multiple equalivalent peaks in the histogram
;	   it returns a warning and no result.
; OPTIONAL OUTPUT
;	h, histogram of data with bin=bin
;	x, the abscissa values for plotting the histogram
; HISTORY
;	LWA, 8-Apr-2001  Written.
;-

if (n_elements(bin) eq 0) then bin = 1
;
data0 = round(data/bin)

h = histogram(data0)
n = n_elements(h)
amin = min(data0)
x = findgen(n)*bin + long(amin)*bin

mm=max(h,ii)
jj=where(h eq mm,nn)	;Test for multiple equal maxima.

if nn gt 1 then begin
   print,'*** There are MULTIPLE, EQUAL-VALUE, PEAKS in the histogram of this array ***'
   return,''
endif

return,x(ii)

end
